FluRS: Streaming Recommendation in Python
==========================================

|Build status| |PyPI version|

.. |Build status| image:: https://github.com/takuti/flurs/actions/workflows/dryrun.yml/badge.svg
   :target: https://github.com/takuti/flurs/actions/workflows/dryrun.yml
.. |PyPI version| image:: https://badge.fury.io/py/flurs.svg
   :target: https://badge.fury.io/py/flurs

**FluRS** is a Python library for online item recommendation. The name indicates *Flu-** (Flux, Fluid, Fluent) *Recommender Systems* which incrementally adapt to dynamic user-item interactions in a streaming environment.

.. image:: https://raw.githubusercontent.com/takuti/flurs/master/doc/images/structure.png
    :width: 512 px

Installation
------------

.. code:: sh

    pip install flurs

Usage
-----

See `documentation <https://flurs.readthedocs.io/>`_ for detail.

Learn More
----------

* `FluRS: A Library for Streaming Recommendation Algorithms <https://speakerdeck.com/takuti/flurs-a-library-for-streaming-recommendation-algorithms>`_ at `EuroSciPy 2017 <https://www.euroscipy.org/2017/>`_ (`video <https://www.youtube.com/watch?v=nARfsX63nDc>`_)
* `FluRS: A Python Library for Online Item Recommendation | takuti.me <https://takuti.me/note/flurs/>`_
* A repository `takuti/stream-recommender <https://github.com/takuti/stream-recommender>`_ uses `FluRS v0.0.1 <https://pypi.python.org/pypi/flurs/0.0.1>`_ to write research papers.
